@@ -5,7 +5,7 @@ import globus_sdk
 
 from globus_cli import utils
 from globus_cli.constants import EXPLICIT_NULL
-from globus_cli.endpointish import EndpointType
+from globus_cli.endpointish import EntityType
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import (
     CommaDelimitedList,
@@ -17,7 +17,12 @@ from globus_cli.parsing import (
     mutex_option_group,
     nullable_multi_callback,
 )
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.termio import Field, TextMode, display
+
+
+class _FullDataField(Field):
+    def get_value(self, data):
+        return super().get_value(data.full_data)
 
 
 def _mkhelp(txt):
@@ -211,7 +216,7 @@ def collection_update(
     """
     gcs_client = login_manager.get_gcs_client(collection_id=collection_id)
 
-    if gcs_client.source_epish.ep_type == EndpointType.GUEST_COLLECTION:
+    if gcs_client.source_epish.entity_type == EntityType.GCSV5_GUEST:
         doc_class: (
             type[globus_sdk.GuestCollectionDocument]
             | type[globus_sdk.MappedCollectionDocument]
@@ -261,8 +266,8 @@ def collection_update(
 
     doc = doc_class(**converted_kwargs)
     res = gcs_client.update_collection(collection_id, doc)
-    formatted_print(
+    display(
         res,
-        fields=[("code", lambda x: x.full_data["code"])],
-        text_format=FORMAT_TEXT_RECORD,
+        fields=[_FullDataField("code", "code")],
+        text_mode=TextMode.text_record,
     )
