@@ -4,7 +4,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command, endpoint_id_arg
-from globus_cli.termio import FORMAT_TEXT_RAW, formatted_print
+from globus_cli.termio import TextMode, display
 
 
 def _spec_to_matches(server_list, server_spec, mode):
@@ -109,4 +109,4 @@ def server_delete(*, login_manager: LoginManager, endpoint_id, server):
 
     response = transfer_client.delete_endpoint_server(endpoint_id, server)
 
-    formatted_print(response, text_format=FORMAT_TEXT_RAW, response_key="message")
+    display(response, text_mode=TextMode.text_raw, response_key="message")
