@@ -1,8 +1,8 @@
-from typing import Any
+import typing as t
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import formatted_print
+from globus_cli.termio import display
 
 from ._common import group_create_and_update_params, group_id_arg
 
@@ -11,7 +11,7 @@ from ._common import group_create_and_update_params, group_id_arg
 @group_id_arg
 @command("update")
 @LoginManager.requires_login(LoginManager.GROUPS_RS)
-def group_update(*, login_manager: LoginManager, group_id: str, **kwargs: Any):
+def group_update(*, login_manager: LoginManager, group_id: str, **kwargs: t.Any):
     """Update an existing group."""
     groups_client = login_manager.get_groups_client()
 
@@ -30,4 +30,4 @@ def group_update(*, login_manager: LoginManager, group_id: str, **kwargs: Any):
 
     response = groups_client.update_group(group_id, data)
 
-    formatted_print(response, simple_text="Group updated successfully")
+    display(response, simple_text="Group updated successfully")
