@@ -1,12 +1,19 @@
 from __future__ import annotations
 
-from typing import Any
+import typing as t
 
 import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import ENDPOINT_PLUS_OPTPATH, command
-from globus_cli.termio import formatted_print, is_verbose, outformat_is_text
+from globus_cli.termio import Field, display, formatters, is_verbose, outformat_is_text
+
+
+class PathItemFormatter(formatters.StrFormatter):
+    def parse(self, data: t.Any) -> str:
+        if not isinstance(data, dict):
+            raise ValueError("cannot parse path item which is not a dict")
+        return str(data["name"]) + ("/" if data["type"] == "dir" else "")
 
 
 @command(
@@ -170,53 +177,54 @@ def ls_command(
     autoactivate(transfer_client, endpoint_id, if_expires_in=60)
 
     # create the query paramaters to send to operation_ls
-    ls_params: dict[str, Any] = {"show_hidden": int(show_hidden)}
+    ls_params: dict[str, t.Any] = {"show_hidden": int(show_hidden)}
     if path:
         ls_params["path"] = path
-    if filter_val:
-        # this char has special meaning in the LS API's filter clause
-        # can't be part of the pattern (but we don't support globbing across
-        # dir structures anyway)
-        if "/" in filter_val:
-            raise click.UsageError('--filter cannot contain "/"')
-        # format into a simple filter clause which operates on filenames
-        ls_params["filter"] = f"name:{filter_val}"
+
+    # this char has special meaning in the LS API's filter clause
+    # can't be part of the pattern (but we don't support globbing across
+    # dir structures anyway)
+    if filter_val and "/" in filter_val:
+        raise click.UsageError('--filter cannot contain "/"')
 
     # get the `ls` result
     if recursive:
-        # NOTE:
-        # --recursive and --filter have an interplay that some users may find
-        # surprising
-        # if we're asked to change or "improve" the behavior in the future, we
-        # could do so with "type:dir" or "type:file" filters added in, and
-        # potentially work out some viable behavior based on what people want
+
+        # if we are doing filtering we need to pass multiple filter params. The
+        # first allows all directories, as we need them for recursive
+        # expansion. The second then filters name by the filter_val
+        if filter_val:
+            ls_params["filter"] = [{"type": "dir"}, {"name": filter_val}]
+
         res: (
             IterableTransferResponse | RecursiveLsResponse
         ) = transfer_client.recursive_operation_ls(
             endpoint_id, ls_params, depth=recursive_depth_limit
         )
     else:
+        # format filter_val into a simple filter clause which operates on name
+        if filter_val:
+            ls_params["filter"] = f"name:{filter_val}"
+
         res = transfer_client.operation_ls(endpoint_id, **ls_params)
 
-    def cleaned_item_name(item):
-        return item["name"] + ("/" if item["type"] == "dir" else "")
-
     # and then print it, per formatting rules
-    formatted_print(
+    pathformatter = PathItemFormatter()
+    display(
         res,
         fields=[
-            ("Permissions", "permissions"),
-            ("User", "user"),
-            ("Group", "group"),
-            ("Size", "size"),
-            ("Last Modified", "last_modified"),
-            ("File Type", "type"),
-            ("Filename", cleaned_item_name),
+            Field("Permissions", "permissions"),
+            Field("User", "user"),
+            Field("Group", "group"),
+            Field("Size", "size"),
+            Field("Last Modified", "last_modified"),
+            Field("File Type", "type"),
+            Field("Filename", "@", formatter=pathformatter),
         ],
         simple_text=(
             None
             if long_output or is_verbose() or not outformat_is_text()
-            else "\n".join(cleaned_item_name(x) for x in res)
+            else "\n".join(pathformatter.parse(x) for x in res)
         ),
         json_converter=iterable_response_to_dict,
     )
