@@ -2,7 +2,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.termio import TextMode, display
 
 from .._common import INDEX_FIELDS
 
@@ -15,8 +15,8 @@ def create_command(*, login_manager: LoginManager, display_name: str, descriptio
     """(BETA) Create a new Index"""
     index_doc = {"display_name": display_name, "description": description}
     search_client = login_manager.get_search_client()
-    formatted_print(
+    display(
         search_client.post("/beta/index", data=index_doc),
-        text_format=FORMAT_TEXT_RECORD,
+        text_mode=TextMode.text_record,
         fields=INDEX_FIELDS,
     )
