@@ -4,7 +4,7 @@ import click
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import formatted_print
+from globus_cli.termio import display
 
 from ..._common import index_id_arg
 
@@ -21,7 +21,7 @@ def delete_command(
 ):
     """Delete a role (requires admin or owner)"""
     search_client = login_manager.get_search_client()
-    formatted_print(
+    display(
         search_client.delete_role(index_id, role_id),
         simple_text=f"Successfully removed role {role_id} from index {index_id}",
     )
