@@ -2,7 +2,7 @@ import uuid
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import FORMAT_TEXT_TABLE, formatted_print
+from globus_cli.termio import Field, TextMode, display
 
 from ..._common import index_id_arg, resolved_principals_field
 
@@ -16,13 +16,13 @@ def list_command(*, login_manager: LoginManager, index_id: uuid.UUID):
     auth_client = login_manager.get_auth_client()
 
     res = search_client.get_role_list(index_id)
-    formatted_print(
+    display(
         res,
         fields=[
-            ("ID", "id"),
-            ("Role", "role_name"),
+            Field("ID", "id"),
+            Field("Role", "role_name"),
             resolved_principals_field(auth_client, res["role_list"]),
         ],
-        text_format=FORMAT_TEXT_TABLE,
+        text_mode=TextMode.text_table,
         response_key="role_list",
     )
