@@ -1,12 +1,12 @@
 from __future__ import annotations
 
 import functools
-from typing import Callable
+import typing as t
 
 import click
 
 
-def task_id_arg(f: Callable | None = None, *, required=True):
+def task_id_arg(f: t.Callable | None = None, *, required=True):
     """
     By default, the task ID is made required; pass `required=False` to the
     decorator arguments to make it optional.
