@@ -18,7 +18,7 @@ from globus_cli.parsing import (
     transfer_recursive_option,
     verify_checksum_option,
 )
-from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.termio import Field, TextMode, display
 
 
 @command(
@@ -225,7 +225,7 @@ def transfer_command(
     Using `--batch`, `globus transfer` can submit a task which transfers multiple files
     or directories. The value for `--batch` can be a file to read from, or the
     character `-` which will read from stdin. From either the file or stdin, each line
-    is treated as a path to a file or directory to delete, respecting quotes.
+    is treated as a path to a file or directory to transfer, respecting quotes.
 
     \b
     Lines are of the form
@@ -353,15 +353,15 @@ def transfer_command(
         raise click.UsageError("--exclude can only be used with --recursive transfers")
 
     if dry_run:
-        formatted_print(
+        display(
             transfer_data.data,
             response_key="DATA",
-            fields=(
-                ("Source Path", "source_path"),
-                ("Dest Path", "destination_path"),
-                ("Recursive", "recursive"),
-                ("External Checksum", lambda x: x.get("external_checksum")),
-            ),
+            fields=[
+                Field("Source Path", "source_path"),
+                Field("Dest Path", "destination_path"),
+                Field("Recursive", "recursive"),
+                Field("External Checksum", "external_checksum"),
+            ],
         )
         # exit safely
         return
@@ -373,8 +373,8 @@ def transfer_command(
         autoactivate(transfer_client, dest_endpoint, if_expires_in=60)
 
     res = transfer_client.submit_transfer(transfer_data)
-    formatted_print(
+    display(
         res,
-        text_format=FORMAT_TEXT_RECORD,
-        fields=(("Message", "message"), ("Task ID", "task_id")),
+        text_mode=TextMode.text_record,
+        fields=[Field("Message", "message"), Field("Task ID", "task_id")],
     )
