@@ -3,12 +3,7 @@ import globus_sdk
 
 from globus_cli.login_manager import LoginManager
 from globus_cli.parsing import command
-from globus_cli.termio import (
-    FORMAT_TEXT_RECORD,
-    formatted_print,
-    is_verbose,
-    print_command_hint,
-)
+from globus_cli.termio import Field, TextMode, display, is_verbose, print_command_hint
 
 
 @command(
@@ -54,7 +49,7 @@ $ globus whoami --linked-identities
     help="Also show identities linked to the currently logged-in primary identity.",
 )
 @LoginManager.requires_login(LoginManager.AUTH_RS)
-def whoami_command(*, login_manager, linked_identities):
+def whoami_command(*, login_manager: LoginManager, linked_identities: bool):
     """
     Display information for the currently logged-in user.
     """
@@ -78,13 +73,13 @@ def whoami_command(*, login_manager, linked_identities):
     # --linked-identities either displays all usernames or a table if verbose
     if linked_identities:
         try:
-            formatted_print(
+            display(
                 res["identity_set"],
                 fields=[
-                    ("Username", "username"),
-                    ("Name", "name"),
-                    ("ID", "sub"),
-                    ("Email", "email"),
+                    Field("Username", "username"),
+                    Field("Name", "name"),
+                    Field("ID", "sub"),
+                    Field("Email", "email"),
                 ],
                 simple_text=(
                     None
@@ -102,14 +97,14 @@ def whoami_command(*, login_manager, linked_identities):
 
     # Default output is the top level data
     else:
-        formatted_print(
+        display(
             res,
-            text_format=FORMAT_TEXT_RECORD,
+            text_mode=TextMode.text_record,
             fields=[
-                ("Username", "preferred_username"),
-                ("Name", "name"),
-                ("ID", "sub"),
-                ("Email", "email"),
+                Field("Username", "preferred_username"),
+                Field("Name", "name"),
+                Field("ID", "sub"),
+                Field("Email", "email"),
             ],
             simple_text=(None if is_verbose() else res["preferred_username"]),
         )
