@@ -2,9 +2,10 @@ from globus_cli import utils
 
 
 class MissingLoginError(ValueError):
-    def __init__(self, missing_servers, *, assume_gcs=False):
+    def __init__(self, missing_servers, *, assume_gcs=False, assume_flow=False):
         self.missing_servers = missing_servers
         self.assume_gcs = assume_gcs
+        self.assume_flow = assume_flow
 
         server_string = utils.format_list_of_words(*missing_servers)
         message_prefix = utils.format_plural_str(
@@ -18,6 +19,10 @@ class MissingLoginError(ValueError):
             login_cmd = "globus login " + " ".join(
                 [f"--gcs {s}" for s in missing_servers]
             )
+        elif assume_flow:
+            login_cmd = "globus login " + " ".join(
+                f"--flow {server}" for server in missing_servers
+            )
 
         self.message = (
             message_prefix + f" for {server_string}, please run\n\n  {login_cmd}\n"
