@@ -1,8 +1,8 @@
 from __future__ import annotations
 
 import functools
+import typing as t
 import uuid
-from typing import TYPE_CHECKING, Iterator
 
 import click
 import globus_sdk
@@ -16,7 +16,7 @@ from globus_sdk.scopes import (
     TransferScopes,
 )
 
-from globus_cli.endpointish import Endpointish, EndpointType
+from globus_cli.endpointish import Endpointish, EntityType
 
 from .. import version
 from .auth_flows import do_link_auth_flow, do_local_server_auth_flow
@@ -25,7 +25,7 @@ from .errors import MissingLoginError
 from .tokenstore import internal_auth_client, token_storage_adapter
 from .utils import is_remote_session
 
-if TYPE_CHECKING:
+if t.TYPE_CHECKING:
     from ..services.auth import CustomAuthClient
     from ..services.gcs import CustomGCSClient
     from ..services.transfer import CustomTransferClient
@@ -78,12 +78,12 @@ class LoginManager:
         self._nonstatic_requirements[rs_name] = scopes
 
     @property
-    def login_requirements(self) -> Iterator[tuple[str, list[str]]]:
+    def login_requirements(self) -> t.Iterator[tuple[str, list[str]]]:
         yield from self.STATIC_SCOPES.items()
         yield from self._nonstatic_requirements.items()
 
     @property
-    def always_required_scopes(self) -> Iterator[str]:
+    def always_required_scopes(self) -> t.Iterator[str]:
         """
         scopes which are required on all login flows, regardless of the specified
         scopes for that flow
@@ -166,14 +166,16 @@ class LoginManager:
         if epilog is not None:
             click.echo(epilog)
 
-    def assert_logins(self, *resource_servers, assume_gcs=False):
+    def assert_logins(self, *resource_servers, assume_gcs=False, assume_flow=False):
         # determine the set of resource servers missing logins
         missing_servers = {s for s in resource_servers if not self.has_login(s)}
 
         # if we are missing logins, assemble error text
         # text is slightly different for 1, 2, or 3+ missing servers
         if missing_servers:
-            raise MissingLoginError(missing_servers, assume_gcs=assume_gcs)
+            raise MissingLoginError(
+                missing_servers, assume_gcs=assume_gcs, assume_flow=assume_flow
+            )
 
     @classmethod
     def requires_login(cls, *resource_servers: str):
@@ -307,12 +309,33 @@ class LoginManager:
             resolved_ep_id = epish.get_collection_endpoint_id()
         elif endpoint_id is not None:
             epish = Endpointish(endpoint_id, transfer_client=transfer_client)
-            epish.assert_ep_type(EndpointType.GCSV5_ENDPOINT)
+            epish.assert_entity_type(EntityType.GCSV5_ENDPOINT)
             resolved_ep_id = str(endpoint_id)
         else:  # pragma: no cover
             raise ValueError("Internal Error! collection_id or endpoint_id is required")
         return (resolved_ep_id, epish)
 
+    def get_specific_flow_client(
+        self,
+        flow_id: uuid.UUID,
+    ) -> globus_sdk.SpecificFlowClient:
+        # Create a SpecificFlowClient without an authorizer
+        # to take advantage of its scope creation code.
+        client = globus_sdk.SpecificFlowClient(flow_id, app_name=version.app_name)
+        assert client.scopes is not None
+        self.add_requirement(client.scopes.resource_server, [client.scopes.user])
+        self.assert_logins(client.scopes.resource_server, assume_flow=True)
+
+        # Create and assign an authorizer now that scope requirements are registered.
+        client.authorizer = self._get_client_authorizer(
+            client.scopes.resource_server,
+            no_tokens_msg=(
+                f"Could not get login data for flow {flow_id}. "
+                f"Try login with '--flow {flow_id}' to fix."
+            ),
+        )
+        return client
+
     def get_gcs_client(
         self,
         *,
