@@ -1,14 +1,15 @@
 from __future__ import annotations
 
-import json
-from typing import Any, Callable, Iterable, Iterator, TextIO, cast
+import typing as t
 
 import click
 
-from globus_cli.types import DATA_CONTAINER_T, FIELD_LIST_T
+from globus_cli.types import DATA_CONTAINER_T, ClickContextTree
 
 
-def get_current_option_help(*, filter_names: Iterable[str] | None = None) -> list[str]:
+def get_current_option_help(
+    *, filter_names: t.Iterable[str] | None = None
+) -> list[str]:
     ctx = click.get_current_context()
     cmd = ctx.command
     opts = [x for x in cmd.params if isinstance(x, click.Option)]
@@ -17,7 +18,7 @@ def get_current_option_help(*, filter_names: Iterable[str] | None = None) -> lis
     return [o.get_error_hint(ctx) for o in opts]
 
 
-def supported_parameters(c: Callable) -> list[str]:
+def supported_parameters(c: t.Callable) -> list[str]:
     import inspect
 
     sig = inspect.signature(c)
@@ -59,66 +60,6 @@ def format_plural_str(
     return formatstr.format(**argdict)
 
 
-class _FuncWithFilterKey:
-    _filter_key: str
-
-
-def sorted_json_field(
-    key: str,
-) -> Callable[[DATA_CONTAINER_T], str]:
-    """Define sorted JSON output for text output containing complex types."""
-
-    def field_func(data: DATA_CONTAINER_T) -> str:
-        return json.dumps(data[key], sort_keys=True)
-
-    ret = cast(_FuncWithFilterKey, field_func)
-    ret._filter_key = key
-    return field_func
-
-
-def filter_fields(
-    check_fields: FIELD_LIST_T,
-    container: DATA_CONTAINER_T,
-) -> FIELD_LIST_T:
-    """
-    Given a set of fields, this is a list of fields actually found in some containing
-    object.
-
-    Always includes keyfunc fields unless they set the magic _filter_key attribute
-    sorted_json_field above is a good example of doing this
-    """
-    fields: FIELD_LIST_T = []
-    for field_to_check in check_fields:
-        # FormatField objects get included always
-        if not isinstance(field_to_check, tuple):
-            fields.append(field_to_check)
-            continue
-
-        name, key = field_to_check
-        check_key = key
-        if callable(key) and hasattr(key, "_filter_key"):
-            check_key = cast(_FuncWithFilterKey, key)._filter_key
-
-        # if it's a string lookup, check if it's contained (and skip if not)
-        if isinstance(check_key, str):
-            subkeys = check_key.split(".")
-            skip_subkey = False
-
-            check_container = container
-            for check_subkey in subkeys[:-1]:
-                if check_subkey not in check_container:
-                    skip_subkey = True
-                    break
-                check_container = check_container[check_subkey]
-            if skip_subkey or subkeys[-1] not in check_container:
-                continue
-
-        # anything else falls through to success
-        # includes keyfuncs which don't set _filter_key
-        fields.append((name, key))
-    return fields
-
-
 class CLIStubResponse:
     """
     A stub response class to make arbitrary data accessible in a way similar to a
@@ -131,7 +72,7 @@ class CLIStubResponse:
     def __contains__(self, key: str) -> bool:
         return key in self.data
 
-    def __getitem__(self, key: str) -> Any:
+    def __getitem__(self, key: str) -> t.Any:
         return self.data[key]
 
 
@@ -139,7 +80,7 @@ class CLIStubResponse:
 class PagingWrapper:
     def __init__(
         self,
-        iterator: Iterator[Any],
+        iterator: t.Iterator[t.Any],
         limit: int | None = None,
         json_conversion_key: str | None = None,
     ) -> None:
@@ -158,7 +99,7 @@ class PagingWrapper:
     def has_next(self) -> bool:
         return self.next is not None
 
-    def __iter__(self) -> Iterator[Any]:
+    def __iter__(self) -> t.Iterator[t.Any]:
         yielded = 0
         while self.has_next() and (self.limit is None or yielded < self.limit):
             cur = self.next
@@ -167,18 +108,20 @@ class PagingWrapper:
             yielded += 1
 
     @property
-    def json_converter(self) -> Callable[[Iterator[Any]], dict[str, list[Any]]]:
+    def json_converter(
+        self,
+    ) -> t.Callable[[t.Iterator[t.Any]], dict[str, list[t.Any]]]:
         if self.json_conversion_key is None:
             raise NotImplementedError("does not support json_converter")
         key: str = self.json_conversion_key
 
-        def converter(it: Iterator[Any]) -> dict[str, list[Any]]:
+        def converter(it: t.Iterator[t.Any]) -> dict[str, list[t.Any]]:
             return {key: list(it)}
 
         return converter
 
 
-def shlex_process_stream(process_command: click.Command, stream: TextIO) -> None:
+def shlex_process_stream(process_command: click.Command, stream: t.TextIO) -> None:
     """
     Use shlex to process stdin line-by-line.
     Also prints help text.
@@ -203,3 +146,33 @@ def shlex_process_stream(process_command: click.Command, stream: TextIO) -> None
             except SystemExit as e:
                 if e.code != 0:
                     raise
+
+
+def walk_contexts(
+    name: str, cmd: click.MultiCommand, parent_ctx: click.Context | None = None
+) -> ClickContextTree:
+    """
+    A recursive walk over click Contexts for all commands in a tree
+    Returns the results in a tree-like structure as triples,
+      (context, subcommands, subgroups)
+
+    subcommands is a list of contexts
+    subgroups is a list of (context, subcommands, subgroups) triples
+    """
+    current_ctx = click.Context(cmd, info_name=name, parent=parent_ctx)
+    cmds, groups = [], []
+    for subcmdname in cmd.list_commands(current_ctx):
+        subcmd = cmd.get_command(current_ctx, subcmdname)
+        # it should be impossible, but if there is no such command, skip
+        if subcmd is None:
+            continue
+        # explicitly skip hidden commands
+        if subcmd.hidden:
+            continue
+
+        if not isinstance(subcmd, click.Group):
+            cmds.append(click.Context(subcmd, info_name=subcmdname, parent=current_ctx))
+        else:
+            groups.append(walk_contexts(subcmdname, subcmd, current_ctx))
+
+    return (current_ctx, cmds, groups)
