@@ -1,13 +1,13 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+import typing as t
 
-if TYPE_CHECKING:
+if t.TYPE_CHECKING:
     from distutils.version import LooseVersion
 
 # single source of truth for package version,
 # see https://packaging.python.org/en/latest/single_source_version/
-__version__ = "3.9.0"
+__version__ = "3.10.1"
 
 # app name to send as part of SDK requests
 app_name = f"Globus CLI v{__version__}"
@@ -29,12 +29,10 @@ def get_versions() -> tuple[LooseVersion | None, LooseVersion]:
     import requests
 
     try:
-        version_data = requests.get(
-            "https://pypi.python.org/pypi/globus-cli/json"
-        ).json()
-        parsed_versions = [LooseVersion(v) for v in version_data["releases"]]
-        latest = max(parsed_versions)
-        return latest, LooseVersion(__version__)
+        response = requests.get("https://pypi.python.org/pypi/globus-cli/json")
     # if the fetch from pypi fails
     except requests.RequestException:
         return None, LooseVersion(__version__)
+    parsed_versions = [LooseVersion(v) for v in response.json()["releases"]]
+    latest = max(parsed_versions)
+    return latest, LooseVersion(__version__)
